---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Affected Components**
A pointer to the component affected by the bug (juturna core library, a built-in node, a plugin node)

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Logs**
If applicable, add logs in a code block to help explain your problem.

**Environment (please complete the following information):**
 - OS: [e.g. Ubuntu]
 - Python Interpreter [e.g. python3.11]
 - Juturna Version [e.g. 1.0.1]

**Additional context**
Add any other context about the problem here
